import { Component, OnInit } from '@angular/core';
import { Subscription } from 'rxjs';
import { Apollo, gql } from 'apollo-angular';

export interface Product {
  id: number;
  manufacturer: string;
  name: string;
  amount: number;
  position: string;
}

@Component({
  selector: 'app-bestand',
  templateUrl: './bestand.component.html',
  styleUrls: ['./bestand.component.scss']
})
export class BestandComponent implements OnInit {
  displayedColumns: string[] = ['id', 'manufacturer', 'name', 'amount', 'position'];
  loading: boolean = true;
  products: Product[] = [];
  private querySubscription: Subscription = new Subscription();

  constructor(private apollo: Apollo) { }

  ngOnInit() {
    this.querySubscription = this.apollo.watchQuery<any>({
      query: gql`query {
          products {
              id,
              manufacturer,
              name,
              amount,
              position
          }
      }`
    })
      .valueChanges
      .subscribe(({ data, loading }) => {
        this.loading = loading;
        this.products = data.products;
      });
  }

  rowClicked(row: Product) {
    window.location.href = "/#/bearbeiten?item=" + row.id
  }

  ngOnDestroy() {
    this.querySubscription.unsubscribe();
  }

}
